from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

MCU_Microchip_SAME = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'ATSAME51J18A-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATSAME51J18A-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-64_10x10mm_P0.5mm', 'keywords':'32-bit ARM Cortex-M4F MCU Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/60001507E.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_SAME.kicad_sym\nATSAME51J18A-A\n\n32-bit ARM Cortex-M4F MCU Microcontroller', 'pins':[
            Pin(num='64',name='PB03',func=pin_types.BIDIR,unit=1),
            Pin(num='1',name='PA00',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB07',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB08',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB09',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA04',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA05',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA06',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA07',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA08',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA09',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA01',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VDDIOB',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA02',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='PA16',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA17',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA18',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA19',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB16',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA03',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB17',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA20',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA21',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA22',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA23',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA24',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA25',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PB22',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB04',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB23',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA27',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='53',name='VDDCORE',func=pin_types.PWROUT,unit=1),
            Pin(num='54',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='VSW',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='PA30',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA31',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB30',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB05',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PB31',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB00',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB01',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB02',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='GNDANA',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VDDANA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PB06',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATSAME53J18A-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATSAME53J18A-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP4.7x4.7mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP4.7x4.7mm', 'keywords':'32-bit ARM Cortex-M4F MCU Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/60001507E.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_SAME.kicad_sym\nATSAME53J18A-M\n\n32-bit ARM Cortex-M4F MCU Microcontroller', 'pins':[
            Pin(num='1',name='PA00',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB07',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB08',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB09',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA04',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA05',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA06',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA07',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA08',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA09',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA01',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VDDIOB',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA02',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='PA16',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA17',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA18',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA19',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB16',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA03',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB17',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA20',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA21',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA22',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA23',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA24',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA25',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PB22',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB04',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB23',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA27',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='53',name='VDDCORE',func=pin_types.PWROUT,unit=1),
            Pin(num='54',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='VSW',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='PA30',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA31',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB30',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB05',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PB31',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB00',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB01',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB02',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PB03',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GNDANA',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VDDANA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PB06',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATSAME54N19A-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATSAME54N19A-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'keywords':'32-bit ARM Cortex-M4F MCU Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/60001507E.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_SAME.kicad_sym\nATSAME54N19A-A\n\n32-bit ARM Cortex-M4F MCU Microcontroller', 'pins':[
            Pin(num='1',name='PA00',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB05',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PB03',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='GNDANA',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VDDANA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='PB06',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB07',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB08',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB09',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA04',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA05',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA06',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA01',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA07',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC05',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC06',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC07',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VDDIOB',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='PA08',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA09',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC00',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDDIOB',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PC01',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC02',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='PA16',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA17',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA18',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA19',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PC16',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC17',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC18',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PC19',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PC03',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PC20',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PC21',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='PB16',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PB17',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PB18',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PB19',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PB20',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB21',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA02',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA20',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA21',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA22',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA23',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PA24',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PA25',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='77',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='78',name='PB22',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB23',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA03',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB24',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PB25',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PC24',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PC25',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PC26',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PC27',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PC28',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PA27',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='89',name='VDDCORE',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='PB04',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='91',name='VSW',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='93',name='PA30',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PA31',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB30',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB31',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PB00',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PB01',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PB02',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATSAME70J21A-AN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATSAME70J21A-AN'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'32-bit ARM Cortex-M7 MCU Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/SAM-E70-S70-V70-V71-Family-Data-Sheet-DS60001527D.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_SAME.kicad_sym\nATSAME70J21A-AN\n\n32-bit ARM Cortex-M7 MCU Microcontroller', 'pins':[
            Pin(num='64',name='VDDPLLUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA21',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA22',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD31',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD25',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD26',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD24',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA24',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VDDCORE',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='PD22',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD21',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDDOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='30',name='PA27',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='NRST',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='TST',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDDIN',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VDDIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='JTAGSEL',func=pin_types.INPUT,unit=1),
            Pin(num='46',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREFP',func=pin_types.INPUT,unit=1),
            Pin(num='50',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VDDPLL',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='VDDIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='DM',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='DP',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VDDCORE',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATSAME70N21A-AN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATSAME70N21A-AN'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'32-bit ARM Cortex-M7 MCU Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/SAM-E70-S70-V70-V71-Family-Data-Sheet-DS60001527D.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_SAME.kicad_sym\nATSAME70N21A-AN\n\n32-bit ARM Cortex-M7 MCU Microcontroller', 'pins':[
            Pin(num='1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='100',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA20',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA19',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA18',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA17',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PD31',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA21',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VDDCORE',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='PD30',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA22',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDDIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PA16',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA23',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD27',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PD25',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PD26',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PD24',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA24',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VDDCORE',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VDDOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='40',name='PA25',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD22',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA26',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PD21',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PD20',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD19',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD18',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VDDIN',func=pin_types.PWRIN,unit=1),
            Pin(num='50',name='PA27',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PD28',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD17',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD16',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='NRST',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VREFN',func=pin_types.INPUT,unit=1),
            Pin(num='60',name='TST',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='VDDIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='69',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='JTAGSEL',func=pin_types.INPUT,unit=1),
            Pin(num='74',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='VDDCORE',func=pin_types.PASSIVE,unit=1),
            Pin(num='77',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PA28',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='80',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VDDIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='PA30',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PA31',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='VDDPLL',func=pin_types.PWRIN,unit=1),
            Pin(num='87',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VREFP',func=pin_types.INPUT,unit=1),
            Pin(num='90',name='VDDPLLUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='91',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='VDDUTMII',func=pin_types.PWRIN,unit=1),
            Pin(num='94',name='HSDM',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='HSDP',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='VDDUTMIC',func=pin_types.PWRIN,unit=1),
            Pin(num='97',name='VBG',func=pin_types.INPUT,unit=1),
            Pin(num='98',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PB9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATSAME70Q21A-AN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATSAME70Q21A-AN'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'32-bit ARM Cortex-M7 MCU Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/SAM-E70-S70-V70-V71-Family-Data-Sheet-DS60001527D.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_SAME.kicad_sym\nATSAME70Q21A-AN\n\n32-bit ARM Cortex-M7 MCU Microcontroller', 'pins':[
            Pin(num='1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PC16',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PC17',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='JTAGSEL',func=pin_types.INPUT,unit=1),
            Pin(num='105',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='VDDCORE',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='PD29',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC18',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PA28',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='116',name='PA30',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC19',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PA31',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC27',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PC20',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PC21',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='VDDPLL',func=pin_types.PWRIN,unit=1),
            Pin(num='124',name='PC22',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PC23',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PA29',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC26',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PC24',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PC25',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='VDDUTMII',func=pin_types.PWRIN,unit=1),
            Pin(num='135',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='HSDM',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='HSDP',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='139',name='VDDUTMIC',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PC31',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='VBG',func=pin_types.INPUT,unit=1),
            Pin(num='141',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='VDDPLLUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='144',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC30',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC29',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD31',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA20',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA19',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA18',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA17',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VDDOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='30',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA21',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VDDCORE',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='PD30',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA22',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VDDIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='PA16',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA23',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD27',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VDDIN',func=pin_types.PWRIN,unit=1),
            Pin(num='50',name='VDDCORE',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PD25',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD26',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD24',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA24',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD23',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PA25',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PD22',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='PA26',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PD21',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PD20',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PD19',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PD18',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA27',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD28',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='VDDIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PD17',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PC28',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD16',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VREFN',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VDDIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='VDDCORE',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='NRST',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='TST',func=pin_types.INPUT,unit=1),
            Pin(num='86',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VREFP',func=pin_types.INPUT,unit=1),
            Pin(num='90',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='96',name='VDDIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='97',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATSAME51J19A-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATSAME51J19A-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_10x10mm_P0.5mm', 'Package_QFP:TQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-64_10x10mm_P0.5mm', 'keywords':'32-bit ARM Cortex-M4F MCU Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/60001507E.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_SAME.kicad_sym\nATSAME51J19A-A\n\n32-bit ARM Cortex-M4F MCU Microcontroller', 'pins':[
            Pin(num='64',name='PB03',func=pin_types.BIDIR,unit=1),
            Pin(num='1',name='PA00',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB07',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB08',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB09',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA04',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA05',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA06',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA07',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA08',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA09',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA01',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VDDIOB',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA02',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='PA16',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA17',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA18',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA19',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB16',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA03',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB17',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA20',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA21',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA22',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA23',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA24',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA25',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PB22',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB04',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB23',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA27',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='53',name='VDDCORE',func=pin_types.PWROUT,unit=1),
            Pin(num='54',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='VSW',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='PA30',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA31',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB30',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB05',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PB31',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB00',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB01',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB02',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='GNDANA',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VDDANA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PB06',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATSAME51J20A-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATSAME51J20A-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_10x10mm_P0.5mm', 'Package_QFP:TQFP-64_10x10mm_P0.5mm', 'Package_QFP:TQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-64_10x10mm_P0.5mm', 'keywords':'32-bit ARM Cortex-M4F MCU Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/60001507E.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_SAME.kicad_sym\nATSAME51J20A-A\n\n32-bit ARM Cortex-M4F MCU Microcontroller', 'pins':[
            Pin(num='64',name='PB03',func=pin_types.BIDIR,unit=1),
            Pin(num='1',name='PA00',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB07',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB08',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB09',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA04',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA05',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA06',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA07',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA08',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA09',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA01',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VDDIOB',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA02',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='PA16',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA17',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA18',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA19',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB16',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA03',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB17',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA20',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA21',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA22',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA23',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA24',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA25',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PB22',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB04',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB23',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA27',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='53',name='VDDCORE',func=pin_types.PWROUT,unit=1),
            Pin(num='54',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='VSW',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='PA30',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA31',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB30',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB05',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PB31',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB00',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB01',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB02',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='GNDANA',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VDDANA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PB06',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATSAME53J19A-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATSAME53J19A-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP4.7x4.7mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP4.7x4.7mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP4.7x4.7mm', 'keywords':'32-bit ARM Cortex-M4F MCU Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/60001507E.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_SAME.kicad_sym\nATSAME53J19A-M\n\n32-bit ARM Cortex-M4F MCU Microcontroller', 'pins':[
            Pin(num='1',name='PA00',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB07',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB08',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB09',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA04',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA05',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA06',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA07',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA08',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA09',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA01',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VDDIOB',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA02',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='PA16',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA17',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA18',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA19',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB16',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA03',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB17',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA20',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA21',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA22',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA23',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA24',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA25',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PB22',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB04',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB23',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA27',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='53',name='VDDCORE',func=pin_types.PWROUT,unit=1),
            Pin(num='54',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='VSW',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='PA30',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA31',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB30',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB05',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PB31',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB00',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB01',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB02',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PB03',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GNDANA',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VDDANA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PB06',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATSAME53J20A-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATSAME53J20A-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP4.7x4.7mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP4.7x4.7mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP4.7x4.7mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP4.7x4.7mm', 'keywords':'32-bit ARM Cortex-M4F MCU Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/60001507E.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_SAME.kicad_sym\nATSAME53J20A-M\n\n32-bit ARM Cortex-M4F MCU Microcontroller', 'pins':[
            Pin(num='1',name='PA00',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB07',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB08',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB09',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA04',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA05',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA06',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA07',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA08',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA09',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA01',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VDDIOB',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA02',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='PA16',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA17',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA18',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA19',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB16',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA03',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB17',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA20',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA21',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA22',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA23',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA24',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA25',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PB22',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB04',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB23',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA27',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='53',name='VDDCORE',func=pin_types.PWROUT,unit=1),
            Pin(num='54',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='VSW',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='PA30',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA31',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB30',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB05',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PB31',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB00',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB01',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB02',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PB03',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GNDANA',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VDDANA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PB06',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATSAME70J19A-AN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATSAME70J19A-AN'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'32-bit ARM Cortex-M7 MCU Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/SAM-E70-S70-V70-V71-Family-Data-Sheet-DS60001527D.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_SAME.kicad_sym\nATSAME70J19A-AN\n\n32-bit ARM Cortex-M7 MCU Microcontroller', 'pins':[
            Pin(num='64',name='VDDPLLUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA21',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA22',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD31',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD25',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD26',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD24',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA24',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VDDCORE',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='PD22',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD21',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDDOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='30',name='PA27',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='NRST',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='TST',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDDIN',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VDDIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='JTAGSEL',func=pin_types.INPUT,unit=1),
            Pin(num='46',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREFP',func=pin_types.INPUT,unit=1),
            Pin(num='50',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VDDPLL',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='VDDIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='DM',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='DP',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VDDCORE',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATSAME70J20A-AN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATSAME70J20A-AN'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'32-bit ARM Cortex-M7 MCU Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/SAM-E70-S70-V70-V71-Family-Data-Sheet-DS60001527D.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_SAME.kicad_sym\nATSAME70J20A-AN\n\n32-bit ARM Cortex-M7 MCU Microcontroller', 'pins':[
            Pin(num='64',name='VDDPLLUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA21',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA22',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD31',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD25',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD26',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD24',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA24',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VDDCORE',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='PD22',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD21',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDDOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='30',name='PA27',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='NRST',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='TST',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDDIN',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VDDIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='JTAGSEL',func=pin_types.INPUT,unit=1),
            Pin(num='46',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREFP',func=pin_types.INPUT,unit=1),
            Pin(num='50',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VDDPLL',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='VDDIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='DM',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='DP',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VDDCORE',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATSAME70N19A-AN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATSAME70N19A-AN'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'32-bit ARM Cortex-M7 MCU Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/SAM-E70-S70-V70-V71-Family-Data-Sheet-DS60001527D.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_SAME.kicad_sym\nATSAME70N19A-AN\n\n32-bit ARM Cortex-M7 MCU Microcontroller', 'pins':[
            Pin(num='1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='100',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA20',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA19',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA18',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA17',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PD31',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA21',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VDDCORE',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='PD30',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA22',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDDIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PA16',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA23',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD27',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PD25',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PD26',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PD24',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA24',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VDDCORE',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VDDOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='40',name='PA25',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD22',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA26',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PD21',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PD20',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD19',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD18',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VDDIN',func=pin_types.PWRIN,unit=1),
            Pin(num='50',name='PA27',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PD28',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD17',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD16',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='NRST',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VREFN',func=pin_types.INPUT,unit=1),
            Pin(num='60',name='TST',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='VDDIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='69',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='JTAGSEL',func=pin_types.INPUT,unit=1),
            Pin(num='74',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='VDDCORE',func=pin_types.PASSIVE,unit=1),
            Pin(num='77',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PA28',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='80',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VDDIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='PA30',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PA31',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='VDDPLL',func=pin_types.PWRIN,unit=1),
            Pin(num='87',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VREFP',func=pin_types.INPUT,unit=1),
            Pin(num='90',name='VDDPLLUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='91',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='VDDUTMII',func=pin_types.PWRIN,unit=1),
            Pin(num='94',name='HSDM',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='HSDP',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='VDDUTMIC',func=pin_types.PWRIN,unit=1),
            Pin(num='97',name='VBG',func=pin_types.INPUT,unit=1),
            Pin(num='98',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PB9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATSAME70N20A-AN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATSAME70N20A-AN'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'32-bit ARM Cortex-M7 MCU Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/SAM-E70-S70-V70-V71-Family-Data-Sheet-DS60001527D.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_SAME.kicad_sym\nATSAME70N20A-AN\n\n32-bit ARM Cortex-M7 MCU Microcontroller', 'pins':[
            Pin(num='1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='100',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA20',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA19',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA18',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA17',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PD31',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA21',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VDDCORE',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='PD30',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA22',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDDIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PA16',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA23',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD27',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PD25',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PD26',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PD24',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA24',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VDDCORE',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VDDOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='40',name='PA25',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD22',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA26',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PD21',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PD20',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD19',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD18',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VDDIN',func=pin_types.PWRIN,unit=1),
            Pin(num='50',name='PA27',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PD28',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD17',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD16',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='NRST',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VREFN',func=pin_types.INPUT,unit=1),
            Pin(num='60',name='TST',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='VDDIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='69',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='JTAGSEL',func=pin_types.INPUT,unit=1),
            Pin(num='74',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='VDDCORE',func=pin_types.PASSIVE,unit=1),
            Pin(num='77',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PA28',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='80',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VDDIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='PA30',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PA31',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='VDDPLL',func=pin_types.PWRIN,unit=1),
            Pin(num='87',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VREFP',func=pin_types.INPUT,unit=1),
            Pin(num='90',name='VDDPLLUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='91',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='VDDUTMII',func=pin_types.PWRIN,unit=1),
            Pin(num='94',name='HSDM',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='HSDP',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='VDDUTMIC',func=pin_types.PWRIN,unit=1),
            Pin(num='97',name='VBG',func=pin_types.INPUT,unit=1),
            Pin(num='98',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PB9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATSAME70Q19A-AN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATSAME70Q19A-AN'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'32-bit ARM Cortex-M7 MCU Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/SAM-E70-S70-V70-V71-Family-Data-Sheet-DS60001527D.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_SAME.kicad_sym\nATSAME70Q19A-AN\n\n32-bit ARM Cortex-M7 MCU Microcontroller', 'pins':[
            Pin(num='1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PC16',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PC17',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='JTAGSEL',func=pin_types.INPUT,unit=1),
            Pin(num='105',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='VDDCORE',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='PD29',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC18',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PA28',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='116',name='PA30',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC19',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PA31',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC27',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PC20',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PC21',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='VDDPLL',func=pin_types.PWRIN,unit=1),
            Pin(num='124',name='PC22',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PC23',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PA29',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC26',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PC24',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PC25',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='VDDUTMII',func=pin_types.PWRIN,unit=1),
            Pin(num='135',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='HSDM',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='HSDP',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='139',name='VDDUTMIC',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PC31',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='VBG',func=pin_types.INPUT,unit=1),
            Pin(num='141',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='VDDPLLUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='144',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC30',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC29',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD31',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA20',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA19',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA18',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA17',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VDDOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='30',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA21',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VDDCORE',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='PD30',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA22',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VDDIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='PA16',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA23',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD27',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VDDIN',func=pin_types.PWRIN,unit=1),
            Pin(num='50',name='VDDCORE',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PD25',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD26',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD24',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA24',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD23',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PA25',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PD22',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='PA26',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PD21',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PD20',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PD19',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PD18',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA27',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD28',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='VDDIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PD17',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PC28',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD16',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VREFN',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VDDIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='VDDCORE',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='NRST',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='TST',func=pin_types.INPUT,unit=1),
            Pin(num='86',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VREFP',func=pin_types.INPUT,unit=1),
            Pin(num='90',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='96',name='VDDIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='97',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATSAME70Q20A-AN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATSAME70Q20A-AN'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'32-bit ARM Cortex-M7 MCU Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/SAM-E70-S70-V70-V71-Family-Data-Sheet-DS60001527D.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_SAME.kicad_sym\nATSAME70Q20A-AN\n\n32-bit ARM Cortex-M7 MCU Microcontroller', 'pins':[
            Pin(num='1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PC16',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PC17',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='JTAGSEL',func=pin_types.INPUT,unit=1),
            Pin(num='105',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='VDDCORE',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='PD29',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC18',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PA28',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='116',name='PA30',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC19',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PA31',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC27',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PC20',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PC21',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='VDDPLL',func=pin_types.PWRIN,unit=1),
            Pin(num='124',name='PC22',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PC23',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PA29',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC26',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PC24',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PC25',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='VDDUTMII',func=pin_types.PWRIN,unit=1),
            Pin(num='135',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='HSDM',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='HSDP',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='139',name='VDDUTMIC',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PC31',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='VBG',func=pin_types.INPUT,unit=1),
            Pin(num='141',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='VDDPLLUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='144',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC30',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC29',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD31',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA20',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA19',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA18',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA17',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VDDOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='30',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA21',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VDDCORE',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='PD30',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA22',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VDDIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='PA16',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA23',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD27',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VDDIN',func=pin_types.PWRIN,unit=1),
            Pin(num='50',name='VDDCORE',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PD25',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD26',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD24',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA24',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD23',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PA25',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PD22',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='PA26',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PD21',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PD20',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PD19',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PD18',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA27',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD28',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='VDDIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PD17',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PC28',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD16',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VREFN',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VDDIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='VDDCORE',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='NRST',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='TST',func=pin_types.INPUT,unit=1),
            Pin(num='86',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VREFP',func=pin_types.INPUT,unit=1),
            Pin(num='90',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='96',name='VDDIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='97',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] })])